#include "z166_kde4_ffmpeg_thumbnails_settings.h"

SettingsWindow::SettingsWindow()
{
	setAttribute( Qt::WA_DeleteOnClose );

	setWindowIcon( KIcon( "view-preview" ) );

	ui.setupUi( this );

	connect( ui.defaultB, SIGNAL( clicked() ), this, SLOT( defaultB() ) );
	connect( ui.cancel, SIGNAL( clicked() ), this, SLOT( close() ) );
	connect( ui.apply, SIGNAL( clicked() ), this, SLOT( apply() ) );
	connect( ui.ok, SIGNAL( clicked() ), this, SLOT( ok() ) );
	connect( ui.removeB, SIGNAL( clicked() ), this, SLOT( removeB() ) );
	connect( ui.addB, SIGNAL( clicked() ), this, SLOT( addB() ) );
	connect( ui.deleteCache, SIGNAL( clicked() ), this, SLOT( deleteCache() ) );

	defaultB();

	settingsFile = QDir::homePath() + "/.z166_kde4_ffmpeg_thumbnails.conf";

	QSettings settings( settingsFile, QSettings::IniFormat );
	if ( settings.contains( "z166_kde4_ffmpeg_thumbnails/blacklistedFileExtensions" ) )
	{
		ui.blacklisted->addItems( settings.value( "z166_kde4_ffmpeg_thumbnails/blacklistedFileExtensions" ).toStringList() );
		ui.blacklisted->setCurrentRow( 0 );
	}
	if ( settings.contains( "z166_kde4_ffmpeg_thumbnails/readFirstXSecondsWhenCantSeek" ) )
		ui.firstXSeconds->setValue( settings.value( "z166_kde4_ffmpeg_thumbnails/readFirstXSecondsWhenCantSeek" ).toInt() );
	if ( settings.contains( "z166_kde4_ffmpeg_thumbnails/lookForKeyframeWhenSeek" ) )
		ui.chkKeyFrame->setChecked( settings.value( "z166_kde4_ffmpeg_thumbnails/lookForKeyframeWhenSeek" ).toBool() );
	if ( settings.contains( "z166_kde4_ffmpeg_thumbnails/seekTo" ) )
		ui.seekTo->setValue( settings.value( "z166_kde4_ffmpeg_thumbnails/seekTo" ).toDouble() * 100 );
	if ( settings.contains( "z166_kde4_ffmpeg_thumbnails/alwaysReadFirstFrame" ) )
		ui.readFirstFrame->setChecked( settings.value( "z166_kde4_ffmpeg_thumbnails/alwaysReadFirstFrame" ).toBool() );

	show();
};

void SettingsWindow::defaultB()
{
	ui.seekTo->setValue( 0.4 * 100 );
	ui.readFirstFrame->setChecked( false );
	ui.chkKeyFrame->setChecked( true );
	ui.firstXSeconds->setValue( 8 );
	ui.blacklisted->clear();
}
void SettingsWindow::apply()
{
	QSettings settings( settingsFile, QSettings::IniFormat );
	QStringList blacklistedFileExtensions;
	for ( int i = 0; i < ui.blacklisted->count() ; i++ )
		blacklistedFileExtensions += ui.blacklisted->item( i )->text();
	settings.setValue( "z166_kde4_ffmpeg_thumbnails/blacklistedFileExtensions", blacklistedFileExtensions );
	settings.setValue( "z166_kde4_ffmpeg_thumbnails/readFirstXSecondsWhenCantSeek", ui.firstXSeconds->value() );
	settings.setValue( "z166_kde4_ffmpeg_thumbnails/lookForKeyframeWhenSeek", ui.chkKeyFrame->isChecked() );
	settings.setValue( "z166_kde4_ffmpeg_thumbnails/seekTo", ui.seekTo->value() / 100. );
	settings.setValue( "z166_kde4_ffmpeg_thumbnails/alwaysReadFirstFrame", ui.readFirstFrame->isChecked() );
}
void SettingsWindow::ok()
{
	apply();
	close();
}
void SettingsWindow::removeB()
{
	if ( ui.blacklisted->currentRow() > -1 )
		delete ui.blacklisted->takeItem( ui.blacklisted->currentRow() );
}
void SettingsWindow::addB()
{
	QString extension = QInputDialog::getText( this, windowTitle(), "File extension" );
	if ( extension.isEmpty() )
		return;
	extension.replace( ".", "" );
	extension.replace( "*", "" );
	extension.replace( " ", "" );
	ui.blacklisted->addItem( extension );
	ui.blacklisted->setCurrentRow( ui.blacklisted->count() - 1 );
}
void SettingsWindow::deleteCache()
{
	QString thumbnailsDir = QDir::homePath() + "/.thumbnails";
	if ( QMessageBox::question( this, windowTitle(), "Do you realy want to delete all thumbnails? ( " + thumbnailsDir + " ) ?", QMessageBox::Yes, QMessageBox::No ) == QMessageBox::Yes )
		KIO::del( thumbnailsDir );
}

int main( int argc, char *argv[] )
{
	new QApplication( argc, argv );
	new SettingsWindow;
	return qApp->exec();
}
